@@ -6,12 +6,12 @@ class Silver(DataLake):
     colums_silver_array = []
 
     def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                 input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin,
-                 colums_silver):
+                 storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name, database,
+                 target, origin, colums_silver):
         self.colums_silver = colums_silver
         super().__init__(spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                         input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target,
-                         origin)
+                         storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name,
+                         database, target, origin)
         self.initialize_variables()
 
     def merge(self):
@@ -25,8 +25,9 @@ class Silver(DataLake):
                     .execute()
             else:
                 self.events.write.format("delta").save(self.mount_data)
-                self.spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database, self.table_name,
-                                                                                                 self.mount_data))
+                self.spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database,
+                                                                                                      self.table_name,
+                                                                                                      self.mount_data))
         except Exception as e:
             print("Error update or create table: " + self.table_name + " explain: " + str(e))
 
